@@ -331,12 +331,15 @@ def main():
         sys.exit(ex)
     result, answer = send_sms(send_args, provider, **send_kwargs)
     print(answer)
-    if (not DEBUG and not args.test and
-            config.has_option('Settings', 'history')):
-        fname = os.path.expanduser(config.get('Settings', 'history'))
-        with open(fname, 'a') as f:
-            f.write("user: %s receiver: %s msg: '%s' response: %s\n" %
-                    (args.id, args.to, message, bcolors.replace(answer)))
+    if DEBUG or (not args.test and config.has_option('Settings', 'history')):
+        log_msg = ("user: %s receiver: %s msg: '%s' response: %s\n" %
+                   (args.id, args.to, message, str(bcolors.replace(answer))))
+        if DEBUG:
+            print(log_msg)
+        else:
+            fname = os.path.expanduser(config.get('Settings', 'history'))
+            with open(fname, 'a') as f:
+                f.write(log_msg)
 
 DEBUG = False
 DEBUG_answer = b"""
